@@ -28,14 +28,13 @@ import tpDcc.config
 import tpDcc.libs.python
 import tpDcc.libs.resources
 import tpDcc.libs.qt.loader
-from tpDcc.core import server, dcc as core_dcc
+from tpDcc.core import utils, server, dcc as core_dcc
 from tpDcc.managers import configs
-from tpDcc.libs.python import python, osplatform, process, path as path_utils
 
 if sys.version_info[0] == 2:
     from socket import error as ConnectionRefusedError
 
-LOGGER = logging.getLogger('tpDcc-core')
+logger = logging.getLogger('tpDcc-core')
 
 
 class BaseClient(QObject):
@@ -114,11 +113,11 @@ class BaseClient(QObject):
 
     def is_valid_reply(self, reply_dict):
         if not reply_dict:
-            LOGGER.debug('Invalid reply')
+            logger.debug('Invalid reply')
             return False
 
         if not reply_dict['success']:
-            LOGGER.error('{} failed: {}'.format(reply_dict['cmd'], reply_dict['msg']))
+            logger.error('{} failed: {}'.format(reply_dict['cmd'], reply_dict['msg']))
             return False
 
         self._status = reply_dict.pop(
@@ -186,10 +185,10 @@ class BaseClient(QObject):
                 msg_str = ''.join(message)
                 self._client_socket.sendall(msg_str.encode())
             except OSError as exc:
-                LOGGER.debug(exc)
+                logger.debug(exc)
                 return None
             except Exception:
-                LOGGER.exception(traceback.format_exc())
+                logger.exception(traceback.format_exc())
                 return None
 
             res = self.recv()
@@ -288,7 +287,7 @@ class BaseClient(QObject):
             self._connected = False
             return False
         except Exception:
-            LOGGER.exception(traceback.format_exc())
+            logger.exception(traceback.format_exc())
             self._status = {'msg': 'Error while connecting client', 'level': self.Status.ERROR}
             self._connected = False
             return False
@@ -375,7 +374,7 @@ class DccClient(BaseClient):
                     client.set_server(server)
                     client.update_client(tool_id=tool_id, **kwargs)
             except Exception as exc:
-                LOGGER.warning(
+                logger.warning(
                     'Impossible to launch tool server! Error while importing: {} >> {}'.format(dcc_mod_name, exc))
                 try:
                     server.close_connection()
@@ -383,7 +382,7 @@ class DccClient(BaseClient):
                     pass
                 return None
         else:
-            client._connect()
+            client._connect(**kwargs)
         #     client.update_client(tool_id=tool_id, **kwargs)
 
         return client
@@ -429,12 +428,12 @@ class DccClient(BaseClient):
 
         msg = 'Connected to: {} {} ({})'.format(dcc_name, dcc_version, dcc_pid)
         self.set_status(msg, self.Status.SUCCESS)
-        LOGGER.info(msg)
+        logger.info(msg)
 
         if tool_id:
             DccClient._register_client(tool_id, self)
 
-    def _connect(self):
+    def _connect(self, **kwargs):
 
         def _connect(_port):
             try:
@@ -447,7 +446,7 @@ class DccClient(BaseClient):
                 self._connected = False
                 return False
             except Exception:
-                LOGGER.exception(traceback.format_exc())
+                logger.exception(traceback.format_exc())
                 self._status = {'msg': 'Error while connecting client', 'level': self.Status.ERROR}
                 self._connected = False
                 return False
@@ -471,32 +470,40 @@ class DccClient(BaseClient):
             supported_dccs = config_dict.get(
                 'supported_dccs', dict()) if config_dict else dict()
 
-        # If no port if given, we check which DCCs are running the user machine and we try to connect
-        # to those ports
-        self._running_dccs = list()
-        for dcc_name in core_dcc.Dccs.ALL:
-
-            if supported_dccs and dcc_name not in supported_dccs:
-                continue
-
-            process_name = core_dcc.Dccs.executables.get(dcc_name, dict()).get(osplatform.get_platform(), None)
-            if not process_name:
-                continue
-            process_running = process.check_if_process_is_running(process_name)
-            if not process_running:
-                continue
-            self._running_dccs.append(dcc_name)
-        if not self._running_dccs:
-            self._port = self.PORT
-            self._connected = _connect(self._port)
+        force_dcc = kwargs.get('dcc', None)
+        if force_dcc and force_dcc in supported_dccs:
+            self._port = core_dcc.dcc_port(self.PORT, dcc_name=force_dcc)
+            self._create_callbacks_server()
+            valid_connect = _connect(self._port)
+            if valid_connect:
+                self._connected = True
         else:
-            for dcc_name in self._running_dccs:
-                self._port = core_dcc.dcc_port(self.PORT, dcc_name=dcc_name)
-                self._create_callbacks_server()
-                valid_connect = _connect(self._port)
-                if valid_connect:
-                    self._connected = True
-                    break
+            # If no port if given, we check which DCCs are running the user machine and we try to connect
+            # to those ports
+            self._running_dccs = list()
+            for dcc_name in core_dcc.Dccs.ALL:
+
+                if supported_dccs and dcc_name not in supported_dccs:
+                    continue
+
+                process_name = core_dcc.Dccs.executables.get(dcc_name, dict()).get(utils.get_platform(), None)
+                if not process_name:
+                    continue
+                process_running = utils.check_if_process_is_running(process_name)
+                if not process_running:
+                    continue
+                self._running_dccs.append(dcc_name)
+            if not self._running_dccs:
+                self._port = self.PORT
+                self._connected = _connect(self._port)
+            else:
+                for dcc_name in self._running_dccs:
+                    self._port = core_dcc.dcc_port(self.PORT, dcc_name=dcc_name)
+                    self._create_callbacks_server()
+                    valid_connect = _connect(self._port)
+                    if valid_connect:
+                        self._connected = True
+                        break
 
         return self._connected
 
@@ -506,7 +513,7 @@ class DccClient(BaseClient):
             try:
                 res = getattr(dcc, cmd)(**cmd_dict)
             except TypeError:
-                if python.is_python2():
+                if utils.is_python2():
                     function_kwargs = inspect.getargspec(getattr(dcc, cmd))
                     plugin_kwargs = function_kwargs.args
                     if not function_kwargs:
@@ -569,7 +576,7 @@ class DccClient(BaseClient):
             dcc_name = core_dcc.Dccs.Unreal
         if not dcc_name:
             msg = 'Executable DCC {} is not supported!'.format(dcc_executable)
-            LOGGER.warning(msg)
+            logger.warning(msg)
             self._status = {'msg': msg, 'level': self.Status.WARNING}
             return False
 
@@ -580,23 +587,23 @@ class DccClient(BaseClient):
             try:
                 self._status = {
                     'msg': 'Error while connecting to Dcc: update dcc paths ...', 'severity': self.Status.ERROR}
-                LOGGER.error('FAILED IMPORT: {} -> {}'.format(str(module_name), str(traceback.format_exc())))
+                logger.error('FAILED IMPORT: {} -> {}'.format(str(module_name), str(traceback.format_exc())))
                 return False
             except Exception:
                 self._status = {
                     'msg': 'Error while connecting to Dcc: update dcc paths ...', 'severity': self.Status.ERROR}
-                LOGGER.error('FAILED IMPORT: {}'.format(module_name))
+                logger.error('FAILED IMPORT: {}'.format(module_name))
                 return False
         if not mod:
             msg = 'Impossible to import DCC specific module: {} ({})'.format(module_name, dcc_name)
-            LOGGER.warning(msg)
+            logger.warning(msg)
             self._status = {'msg': msg, 'severity': self.Status.WARNING}
             return False
 
         cmd = {
             'cmd': 'update_dcc_paths',
             'paths': OrderedDict({
-                'tpDcc.dccs.{}'.format(dcc_name): path_utils.clean_path(
+                'tpDcc.dccs.{}'.format(dcc_name): utils.clean_path(
                     os.path.dirname(os.path.dirname(os.path.dirname(os.path.dirname(mod.get_filename())))))
             })
         }
@@ -733,16 +740,16 @@ class DccClient(BaseClient):
         """
 
         return {
-            'tpDcc.loader': path_utils.clean_path(os.path.dirname(os.path.dirname(tpDcc.loader.__file__))),
-            'tpDcc.config': path_utils.clean_path(
+            'tpDcc.loader': utils.clean_path(os.path.dirname(os.path.dirname(tpDcc.loader.__file__))),
+            'tpDcc.config': utils.clean_path(
                 os.path.dirname(os.path.dirname(os.path.dirname(tpDcc.config.__file__)))),
-            'tpDcc.libs.python': path_utils.clean_path(
+            'tpDcc.libs.python': utils.clean_path(
                 os.path.dirname(
                     os.path.dirname(os.path.dirname(os.path.dirname(tpDcc.libs.python.__file__))))),
-            'tpDcc.libs.resources': path_utils.clean_path(
+            'tpDcc.libs.resources': utils.clean_path(
                 os.path.dirname(
                     os.path.dirname(os.path.dirname(os.path.dirname(tpDcc.libs.resources.__file__))))),
-            'tpDcc.libs.qt.loader': path_utils.clean_path(
+            'tpDcc.libs.qt.loader': utils.clean_path(
                 os.path.dirname(os.path.dirname(os.path.dirname(os.path.dirname(tpDcc.libs.qt.loader.__file__)))))
         }
 
